@@ -30,12 +30,6 @@
 
 #include "gvc-balance-bar.h"
 
-#define BALANCE_BAR_STYLE                                       \
-        "style \"balance-bar-scale-style\" {\n"                 \
-        " GtkScale::trough-side-details = 0\n"                  \
-        "}\n"                                                   \
-        "widget \"*.balance-bar-scale\" style : rc \"balance-bar-scale-style\"\n"
-
 #define SCALE_SIZE 128
 
 struct _GvcBalanceBarPrivate
@@ -482,15 +476,17 @@ on_adjustment_value_changed (GtkAdjustment *adjustment, GvcBalanceBar *bar)
 
         switch (bar->priv->btype) {
         case BALANCE_TYPE_RL:
-                mate_mixer_stream_control_set_balance (bar->priv->control, value);
+                mate_mixer_stream_control_set_balance (bar->priv->control,
+                                                       (gfloat) value);
                 break;
         case BALANCE_TYPE_FR:
-                mate_mixer_stream_control_set_fade (bar->priv->control, value);
+                mate_mixer_stream_control_set_fade (bar->priv->control,
+                                                    (gfloat) value);
                 break;
         case BALANCE_TYPE_LFE:
                 mate_mixer_stream_control_set_channel_volume (bar->priv->control,
-                                                      bar->priv->lfe_channel,
-                                                      value);
+                                                              bar->priv->lfe_channel,
+                                                              (guint) value);
                 break;
         }
 }
